Class: Faker::Creature::Dog::Dalmatian

Inherits:
Base
  • Object
show all
Defined in:
lib/faker/creature/dog/dalmatian.rb

Overview

Life is more fun with spots.

Constant Summary collapse

VERSION =
'0.1.0'

Class Method Summary collapse

Class Method Details

.classic_nameString

Produce a random name for a Dalmatian, limited to the original Hundred and One.

Examples:

Faker::Creature::Dog::Dalmatian.classic_name #=> "Perdita"

Returns:

  • (String)


37
38
39
# File 'lib/faker/creature/dog/dalmatian.rb', line 37

def classic_name
  fetch('creature.dog.dalmatian.classic_name')
end

.nameString

Produce a random name for a Dalmatian.

Examples:

Faker::Creature::Dog::Dalmatian.name #=> "Da Vinci"

Returns:

  • (String)


26
27
28
# File 'lib/faker/creature/dog/dalmatian.rb', line 26

def name
  fetch('creature.dog.dalmatian.name')
end

.one_hundred_and_two_nameString

Produce a random name for a Dalmatian, limited to the 102 Dalmatians film.

Examples:

Faker::Creature::Dog::Dalmatian.one_hundred_and_two_name #=> "Domino"

Returns:

  • (String)


71
72
73
# File 'lib/faker/creature/dog/dalmatian.rb', line 71

def one_hundred_and_two_name
  fetch('creature.dog.dalmatian.102_name')
end

Produce a random name for a Dalmatian, limited to ‘popular’ Dalmatians. Basically, the ones who have developed personalities in at least one media.

Examples:

Faker::Creature::Dog::Dalmatian.popular_name #=> "Cadpig"

Returns:

  • (String)


49
50
51
# File 'lib/faker/creature/dog/dalmatian.rb', line 49

def popular_name
  fetch('creature.dog.dalmatian.popular_name')
end

.series_episodeString

Produce a random episode title from the original series.

Examples:

Faker::Creature::Dog::Dalmatian.series_episode #=> "You Slipped a Disk"

Returns:

  • (String)


82
83
84
# File 'lib/faker/creature/dog/dalmatian.rb', line 82

def series_episode
  fetch('creature.dog.dalmatian.series_episode')
end

.street_episodeString

Produce a random episode title from 101 Dalmatian Street.

Examples:

Faker::Creature::Dog::Dalmatian.street_episode #=> "Doggy Da Vinci"

Returns:

  • (String)


93
94
95
# File 'lib/faker/creature/dog/dalmatian.rb', line 93

def street_episode
  fetch('creature.dog.dalmatian.street_episode')
end

.street_nameString

Produce a random name for a Dalmatian, limited to 101 Dalmatian Street.

Examples:

Faker::Creature::Dog::Dalmatian.street_name #=> "Delilah"

Returns:

  • (String)


60
61
62
# File 'lib/faker/creature/dog/dalmatian.rb', line 60

def street_name
  fetch('creature.dog.dalmatian.street_name')
end