Class: Faker::Creature::Dog::Dalmatian
- Inherits:
-
Base
- Object
- Base
- Faker::Creature::Dog::Dalmatian
- Defined in:
- lib/faker/creature/dog/dalmatian.rb
Overview
Life is more fun with spots.
Constant Summary collapse
- VERSION =
'0.1.0'
Class Method Summary collapse
-
.classic_name ⇒ String
Produce a random name for a Dalmatian, limited to the original Hundred and One.
-
.name ⇒ String
Produce a random name for a Dalmatian.
-
.one_hundred_and_two_name ⇒ String
Produce a random name for a Dalmatian, limited to the 102 Dalmatians film.
-
.popular_name ⇒ String
Produce a random name for a Dalmatian, limited to ‘popular’ Dalmatians.
-
.series_episode ⇒ String
Produce a random episode title from the original series.
-
.street_episode ⇒ String
Produce a random episode title from 101 Dalmatian Street.
-
.street_name ⇒ String
Produce a random name for a Dalmatian, limited to 101 Dalmatian Street.
Class Method Details
.classic_name ⇒ String
Produce a random name for a Dalmatian, limited to the original Hundred and One.
37 38 39 |
# File 'lib/faker/creature/dog/dalmatian.rb', line 37 def classic_name fetch('creature.dog.dalmatian.classic_name') end |
.name ⇒ String
Produce a random name for a Dalmatian.
26 27 28 |
# File 'lib/faker/creature/dog/dalmatian.rb', line 26 def name fetch('creature.dog.dalmatian.name') end |
.one_hundred_and_two_name ⇒ String
Produce a random name for a Dalmatian, limited to the 102 Dalmatians film.
71 72 73 |
# File 'lib/faker/creature/dog/dalmatian.rb', line 71 def one_hundred_and_two_name fetch('creature.dog.dalmatian.102_name') end |
.popular_name ⇒ String
Produce a random name for a Dalmatian, limited to ‘popular’ Dalmatians. Basically, the ones who have developed personalities in at least one media.
49 50 51 |
# File 'lib/faker/creature/dog/dalmatian.rb', line 49 def popular_name fetch('creature.dog.dalmatian.popular_name') end |
.series_episode ⇒ String
Produce a random episode title from the original series.
82 83 84 |
# File 'lib/faker/creature/dog/dalmatian.rb', line 82 def series_episode fetch('creature.dog.dalmatian.series_episode') end |
.street_episode ⇒ String
Produce a random episode title from 101 Dalmatian Street.
93 94 95 |
# File 'lib/faker/creature/dog/dalmatian.rb', line 93 def street_episode fetch('creature.dog.dalmatian.street_episode') end |
.street_name ⇒ String
Produce a random name for a Dalmatian, limited to 101 Dalmatian Street.
60 61 62 |
# File 'lib/faker/creature/dog/dalmatian.rb', line 60 def street_name fetch('creature.dog.dalmatian.street_name') end |